libxbps: detection of orphaned packages is now 66% faster.

This commit is contained in:
Juan RP committed 2015-01-10 05:43:35 +01:00
1 parent 0ec2dd98ce
commit 1f6a5c0e47
5 files changed
+83 -34

No files matched your search

+4
View File
@@ -1,5 +1,9 @@
xbps-0.44 (???):
* libxbps: detection of orphaned pkgs is now 66% faster (and even more in some cases).
This improves the performance of `xbps-remove -R` (recursively remove a pkg
and its dependencies) and `xbps-remove -o` (remove orphaned pkgs) marginally.
* xbps-query(8): only compile the ERE (Extended Regular Expression) once in
the ownedby mode. A performance improvement suggested by Christian Neukirchen.